==> cohesity_management_sdk-1.6.4.tar.gz: cohesity_management_sdk-1.6.4/cohesity_management_sdk/models_v2/object_type_5_enum.py <==
# -*- coding: utf-8 -*-

class ObjectType5Enum(object):

    """Implementation of the 'ObjectType5' enum.

    Specifies the type of the object.

    Attributes:
        KCLUSTER: TODO: type description here.
        KVSERVER: TODO: type description here.
        KVOLUME: TODO: type description here.
        KVCENTER: TODO: type description here.
        KSTANDALONEHOST: TODO: type description here.
        KVCLOUDDIRECTOR: TODO: type description here.
        KFOLDER: TODO: type description here.
        KDATACENTER: TODO: type description here.
        KCOMPUTERESOURCE: TODO: type description here.
        KCLUSTERCOMPUTERESOURCE: TODO: type description here.
        KRESOURCEPOOL: TODO: type description here.
        KDATASTORE: TODO: type description here.
        KHOSTSYSTEM: TODO: type description here.
        KVIRTUALMACHINE: TODO: type description here.
        KVIRTUALAPP: TODO: type description here.
        KSTORAGEPOD: TODO: type description here.
        KNETWORK: TODO: type description here.
        KDISTRIBUTEDVIRTUALPORTGROUP: TODO: type description here.
        KTAGCATEGORY: TODO: type description here.
        KTAG: TODO: type description here.
        KOPAQUENETWORK: TODO: type description here.
        KORGANIZATION: TODO: type description here.
        KVIRTUALDATACENTER: TODO: type description here.
        KCATALOG: TODO: type description here.
        KORGMETADATA: TODO: type description here.
        KSTORAGEPOLICY: TODO: type description here.
        KVIRTUALAPPTEMPLATE: TODO: type description here.
        KDOMAIN: TODO: type description here.
        KOUTLOOK: TODO: type description here.
        KMAILBOX: TODO: type description here.
        KUSERS: TODO: type description here.
        KGROUPS: TODO: type description here.
        KSITES: TODO: type description here.
        KUSER: TODO: type description here.
        KGROUP: TODO: type description here.
        KSITE: TODO: type description here.
        KAPPLICATION: TODO: type description here.
        KGRAPHUSER: TODO: type description here.
        KPUBLICFOLDERS: TODO: type description here.
        KPUBLICFOLDER: TODO: type description here.
        KKEYSPACE: TODO: type description here.
        KTABLE: TODO: type description here.
        KDATABASE: TODO: type description here.
        KCOLLECTION: TODO: type description here.
        KBUCKET: TODO: type description here.
        KNAMESPACE: TODO: type description here.
        KSCVMMSERVER: TODO: type description here.
        KSTANDALONECLUSTER: TODO: type description here.
        KHOSTGROUP: TODO: type description here.
        KHYPERVHOST: TODO: type description here.
        KHOSTCLUSTER: TODO: type description here.
        KCUSTOMPROPERTY: TODO: type description here.
        KSUBSCRIPTION: TODO: type description here.
        KRESOURCEGROUP: TODO: type description here.
        KSTORAGEACCOUNT: TODO: type description here.
        KSTORAGEKEY: TODO: type description here.
        KSTORAGECONTAINER: TODO: type description here.
        KSTORAGEBLOB: TODO: type description here.
        KNETWORKSECURITYGROUP: TODO: type description here.
        KVIRTUALNETWORK: TODO: type description here.
        KSUBNET: TODO: type description here.
        KCOMPUTEOPTIONS: TODO: type description here.
        KSNAPSHOTMANAGERPERMIT: TODO: type description here.
        KOVIRTMANAGER: TODO: type description here.
        KHOST: TODO: type description here.
        KSTORAGEDOMAIN: TODO: type description here.
        KVNICPROFILE: TODO: type description here.
        KIAMUSER: TODO: type description here.
        KREGION: TODO: type description here.
        KAVAILABILITYZONE: TODO: type description here.
        KEC2INSTANCE: TODO: type description here.
        KVPC: TODO: type description here.
        KINSTANCETYPE: TODO: type description here.
        KKEYPAIR: TODO: type description here.
        KRDSOPTIONGROUP: TODO: type description here.
        KRDSPARAMETERGROUP: TODO: type description here.
        KRDSINSTANCE: TODO: type description here.
        KRDSSUBNET: TODO: type description here.
        KRDSTAG: TODO: type description here.
        KACCOUNT: TODO: type description here.
        KSUBTASKPERMIT: TODO: type description here.
        KPROJECT: TODO: type description here.
        KLABEL: TODO: type description here.
        KMETADATA: TODO: type description here.
        KVPCCONNECTOR: TODO: type description here.
        KPRISMCENTRAL: TODO: type description here.
        KDFSGROUP: TODO: type description here.
        KDFSTOPDIR: TODO: type description here.
        KZONE: TODO: type description here.
        KMOUNTPOINT: TODO: type description here.
        KSTORAGEARRAY: TODO: type description here.
        KFILESYSTEM: TODO: type description here.
        KCONTAINER: TODO: type description here.
        KFILESYSTEM1: TODO: type description here.
        KFILESET: TODO: type description here.
        KVIEWBOX: TODO: type description here.
        KVIEW: TODO: type description here.
        KWINDOWSCLUSTER: TODO: type description here.
        KORACLERACCLUSTER: TODO: type description here.
        KORACLEAPCLUSTER: TODO: type description here.
        KSERVICE: TODO: type description here.
        KPVC: TODO: type description here.
        KROOTCONTAINER: TODO: type description here.
        KDAGROOTCONTAINER: TODO: type description here.
        KEXCHANGENODE: TODO: type description here.
        KEXCHANGEDAGDATABASECOPY: TODO: type description here.
        KEXCHANGESTANDALONEDATABASE: TODO: type description here.
        KEXCHANGEDAG: TODO: type description here.
        KEXCHANGEDAGDATABASE: TODO: type description here.
        KDOMAINCONTROLLER: TODO: type description here.
        KINSTANCE: TODO: type description here.
        KAAG: TODO: type description here.
        KAAGROOTCONTAINER: TODO: type description here.
        KRACROOTCONTAINER: TODO: type description here.
        KTABLESPACE: TODO: type description here.
        KPDB: TODO: type description here.

    """

    KCLUSTER = 'kCluster'

    KVSERVER = 'kVserver'

    KVOLUME = 'kVolume'

    KVCENTER = 'kVCenter'

    KSTANDALONEHOST = 'kStandaloneHost'

    K_VCLOUD_DIRECTOR = 'kvCloudDirector'

    KFOLDER = 'kFolder'

    KDATACENTER = 'kDatacenter'

    KCOMPUTERESOURCE = 'kComputeResource'

    KCLUSTERCOMPUTERESOURCE = 'kClusterComputeResource'

    KRESOURCEPOOL = 'kResourcePool'

    KDATASTORE = 'kDatastore'

    KHOSTSYSTEM = 'kHostSystem'

    KVIRTUALMACHINE = 'kVirtualMachine'

    KVIRTUALAPP = 'kVirtualApp'

    KSTORAGEPOD = 'kStoragePod'

    KNETWORK = 'kNetwork'

    KDISTRIBUTEDVIRTUALPORTGROUP = 'kDistributedVirtualPortgroup'

    KTAGCATEGORY = 'kTagCategory'

    KTAG = 'kTag'

    KOPAQUENETWORK = 'kOpaqueNetwork'

    KORGANIZATION = 'kOrganization'

    KVIRTUALDATACENTER = 'kVirtualDatacenter'

    KCATALOG = 'kCatalog'

    KORGMETADATA = 'kOrgMetadata'

    KSTORAGEPOLICY = 'kStoragePolicy'

    KVIRTUALAPPTEMPLATE = 'kVirtualAppTemplate'

    KDOMAIN = 'kDomain'

    KOUTLOOK = 'kOutlook'

    KMAILBOX = 'kMailbox'

    KUSERS = 'kUsers'

    KGROUPS = 'kGroups'

    KSITES = 'kSites'

    KUSER = 'kUser'

    KGROUP = 'kGroup'

    KSITE = 'kSite'

    KAPPLICATION = 'kApplication'

    KGRAPHUSER = 'kGraphUser'

    KPUBLICFOLDERS = 'kPublicFolders'

    KPUBLICFOLDER = 'kPublicFolder'

    KKEYSPACE = 'kKeyspace'

    KTABLE = 'kTable'

    KDATABASE = 'kDatabase'

    KCOLLECTION = 'kCollection'

    KBUCKET = 'kBucket'

    KNAMESPACE = 'kNamespace'

    KSCVMMSERVER = 'kSCVMMServer'

    KSTANDALONECLUSTER = 'kStandaloneCluster'

    KHOSTGROUP = 'kHostGroup'

    K_HYPERV_HOST = 'kHypervHost'

    KHOSTCLUSTER = 'kHostCluster'

    KCUSTOMPROPERTY = 'kCustomProperty'

    KSUBSCRIPTION = 'kSubscription'

    KRESOURCEGROUP = 'kResourceGroup'

    KSTORAGEACCOUNT = 'kStorageAccount'

    KSTORAGEKEY = 'kStorageKey'

    KSTORAGECONTAINER = 'kStorageContainer'

    KSTORAGEBLOB = 'kStorageBlob'

    KNETWORKSECURITYGROUP = 'kNetworkSecurityGroup'

    KVIRTUALNETWORK = 'kVirtualNetwork'

    KSUBNET = 'kSubnet'

    KCOMPUTEOPTIONS = 'kComputeOptions'

    KSNAPSHOTMANAGERPERMIT = 'kSnapshotManagerPermit'

    KOVIRTMANAGER = 'kOVirtManager'

    KHOST = 'kHost'

    KSTORAGEDOMAIN = 'kStorageDomain'

    KVNICPROFILE = 'kVNicProfile'

    KIAMUSER = 'kIAMUser'

    KREGION = 'kRegion'

    KAVAILABILITYZONE = 'kAvailabilityZone'

    KEC2INSTANCE = 'kEC2Instance'

    KVPC = 'kVPC'

    KINSTANCETYPE = 'kInstanceType'

    KKEYPAIR = 'kKeyPair'

    KRDSOPTIONGROUP = 'kRDSOptionGroup'

    KRDSPARAMETERGROUP = 'kRDSParameterGroup'

    KRDSINSTANCE = 'kRDSInstance'

    KRDSSUBNET = 'kRDSSubnet'

    KRDSTAG = 'kRDSTag'

    KACCOUNT = 'kAccount'

    KSUBTASKPERMIT = 'kSubTaskPermit'

    KPROJECT = 'kProject'

    KLABEL = 'kLabel'

    KMETADATA = 'kMetadata'

    KVPCCONNECTOR = 'kVPCConnector'

    KPRISMCENTRAL = 'kPrismCentral'

    KDFSGROUP = 'kDfsGroup'

    KDFSTOPDIR = 'kDfsTopDir'

    KZONE = 'kZone'

    KMOUNTPOINT = 'kMountPoint'

    KSTORAGEARRAY = 'kStorageArray'

    KFILESYSTEM = 'kFileSystem'

    KCONTAINER = 'kContainer'

    KFILESYSTEM1 = 'kFilesystem'

    KFILESET = 'kFileset'

    KVIEWBOX = 'kViewBox'

    KVIEW = 'kView'

    KWINDOWSCLUSTER = 'kWindowsCluster'

    KORACLERACCLUSTER = 'kOracleRACCluster'

    KORACLEAPCLUSTER = 'kOracleAPCluster'

    KSERVICE = 'kService'

    KPVC = 'kPVC'

    KROOTCONTAINER = 'kRootContainer'

    KDAGROOTCONTAINER = 'kDAGRootContainer'

    KEXCHANGENODE = 'kExchangeNode'

    KEXCHANGEDAGDATABASECOPY = 'kExchangeDAGDatabaseCopy'

    KEXCHANGESTANDALONEDATABASE = 'kExchangeStandaloneDatabase'

    KEXCHANGEDAG = 'kExchangeDAG'

    KEXCHANGEDAGDATABASE = 'kExchangeDAGDatabase'

    KDOMAINCONTROLLER = 'kDomainController'

    KINSTANCE = 'kInstance'

    KAAG = 'kAAG'

    KAAGROOTCONTAINER = 'kAAGRootContainer'

    KRACROOTCONTAINER = 'kRACRootContainer'

    KTABLESPACE = 'kTableSpace'

    KPDB = 'kPDB'

==> cohesity_management_sdk-1.6.15.tar.gz: cohesity_management_sdk-1.6.15/cohesity_management_sdk/models_v2/object_type_5_enum.py <==
# -*- coding: utf-8 -*-

class ObjectType5Enum(object):

    """Implementation of the 'ObjectType5' enum.

    Specifies the type of the object.

    Attributes:
        KCLUSTER: TODO: type description here.
        KVSERVER: TODO: type description here.
        KVOLUME: TODO: type description here.
        KVCENTER: TODO: type description here.
        KSTANDALONEHOST: TODO: type description here.
        KVCLOUDDIRECTOR: TODO: type description here.
        KFOLDER: TODO: type description here.
        KDATACENTER: TODO: type description here.
        KCOMPUTERESOURCE: TODO: type description here.
        KCLUSTERCOMPUTERESOURCE: TODO: type description here.
        KRESOURCEPOOL: TODO: type description here.
        KDATASTORE: TODO: type description here.
        KHOSTSYSTEM: TODO: type description here.
        KVIRTUALMACHINE: TODO: type description here.
        KVIRTUALAPP: TODO: type description here.
        KSTORAGEPOD: TODO: type description here.
        KNETWORK: TODO: type description here.
        KDISTRIBUTEDVIRTUALPORTGROUP: TODO: type description here.
        KTAGCATEGORY: TODO: type description here.
        KTAG: TODO: type description here.
        KOPAQUENETWORK: TODO: type description here.
        KORGANIZATION: TODO: type description here.
        KVIRTUALDATACENTER: TODO: type description here.
        KCATALOG: TODO: type description here.
        KORGMETADATA: TODO: type description here.
        KSTORAGEPOLICY: TODO: type description here.
        KVIRTUALAPPTEMPLATE: TODO: type description here.
        KDOMAIN: TODO: type description here.
        KOUTLOOK: TODO: type description here.
        KMAILBOX: TODO: type description here.
        KUSERS: TODO: type description here.
        KGROUPS: TODO: type description here.
        KSITES: TODO: type description here.
        KUSER: TODO: type description here.
        KGROUP: TODO: type description here.
        KSITE: TODO: type description here.
        KAPPLICATION: TODO: type description here.
        KGRAPHUSER: TODO: type description here.
        KPUBLICFOLDERS: TODO: type description here.
        KPUBLICFOLDER: TODO: type description here.
        KTEAMS: TODO: type description here.
        KTEAM: TODO: type description here.
        KKEYSPACE: TODO: type description here.
        KTABLE: TODO: type description here.
        KDATABASE: TODO: type description here.
        KCOLLECTION: TODO: type description here.
        KBUCKET: TODO: type description here.
        KNAMESPACE: TODO: type description here.
        KSCVMMSERVER: TODO: type description here.
        KSTANDALONECLUSTER: TODO: type description here.
        KHOSTGROUP: TODO: type description here.
        KHYPERVHOST: TODO: type description here.
        KHOSTCLUSTER: TODO: type description here.
        KCUSTOMPROPERTY: TODO: type description here.
        KSUBSCRIPTION: TODO: type description here.
        KRESOURCEGROUP: TODO: type description here.
        KSTORAGEACCOUNT: TODO: type description here.
        KSTORAGEKEY: TODO: type description here.
        KSTORAGECONTAINER: TODO: type description here.
        KSTORAGEBLOB: TODO: type description here.
        KNETWORKSECURITYGROUP: TODO: type description here.
        KVIRTUALNETWORK: TODO: type description here.
        KSUBNET: TODO: type description here.
        KCOMPUTEOPTIONS: TODO: type description here.
        KSNAPSHOTMANAGERPERMIT: TODO: type description here.
        KAVAILABILITYSET: TODO: type description here.
        KOVIRTMANAGER: TODO: type description here.
        KHOST: TODO: type description here.
        KSTORAGEDOMAIN: TODO: type description here.
        KVNICPROFILE: TODO: type description here.
        KIAMUSER: TODO: type description here.
        KREGION: TODO: type description here.
        KAVAILABILITYZONE: TODO: type description here.
        KEC2INSTANCE: TODO: type description here.
        KVPC: TODO: type description here.
        KINSTANCETYPE: TODO: type description here.
        KKEYPAIR: TODO: type description here.
        KRDSOPTIONGROUP: TODO: type description here.
        KRDSPARAMETERGROUP: TODO: type description here.
        KRDSINSTANCE: TODO: type description here.
        KRDSSUBNET: TODO: type description here.
        KRDSTAG: TODO: type description here.
        KAURORACLUSTER: TODO: type description here.
        KACCOUNT: TODO: type description here.
        KSUBTASKPERMIT: TODO: type description here.
        KPROJECT: TODO: type description here.
        KLABEL: TODO: type description here.
        KMETADATA: TODO: type description here.
        KVPCCONNECTOR: TODO: type description here.
        KPRISMCENTRAL: TODO: type description here.
        KOTHERHYPERVISORCLUSTER: TODO: type description here.
        KDFSGROUP: TODO: type description here.
        KDFSTOPDIR: TODO: type description here.
        KZONE: TODO: type description here.
        KMOUNTPOINT: TODO: type description here.
        KSTORAGEARRAY: TODO: type description here.
        KFILESYSTEM: TODO: type description here.
        KCONTAINER: TODO: type description here.
        KFILESYSTEM: TODO: type description here.
        KFILESET: TODO: type description here.
        KVIEWBOX: TODO: type description here.
        KVIEW: TODO: type description here.
        KWINDOWSCLUSTER: TODO: type description here.
        KORACLERACCLUSTER: TODO: type description here.
        KORACLEAPCLUSTER: TODO: type description here.
        KSERVICE: TODO: type description here.
        KPVC: TODO: type description here.
        KROOTCONTAINER: TODO: type description here.
        KDAGROOTCONTAINER: TODO: type description here.
        KEXCHANGENODE: TODO: type description here.
        KEXCHANGEDAGDATABASECOPY: TODO: type description here.
        KEXCHANGESTANDALONEDATABASE: TODO: type description here.
        KEXCHANGEDAG: TODO: type description here.
        KEXCHANGEDAGDATABASE: TODO: type description here.
        KDOMAINCONTROLLER: TODO: type description here.
        KINSTANCE: TODO: type description here.
        KAAG: TODO: type description here.
        KAAGROOTCONTAINER: TODO: type description here.
        KRACROOTCONTAINER: TODO: type description here.
        KTABLESPACE: TODO: type description here.
        KPDB: TODO: type description here.
        KOBJECT: TODO: type description here.

    """

    KCLUSTER = 'kCluster'

    KVSERVER = 'kVserver'

    KVOLUME = 'kVolume'

    KVCENTER = 'kVCenter'

    KSTANDALONEHOST = 'kStandaloneHost'

    KVCLOUDDIRECTOR = 'kvCloudDirector'

    KFOLDER = 'kFolder'

    KDATACENTER = 'kDatacenter'

    KCOMPUTERESOURCE = 'kComputeResource'

    KCLUSTERCOMPUTERESOURCE = 'kClusterComputeResource'

    KRESOURCEPOOL = 'kResourcePool'

    KDATASTORE = 'kDatastore'

    KHOSTSYSTEM = 'kHostSystem'

    KVIRTUALMACHINE = 'kVirtualMachine'

    KVIRTUALAPP = 'kVirtualApp'

    KSTORAGEPOD = 'kStoragePod'

    KNETWORK = 'kNetwork'

    KDISTRIBUTEDVIRTUALPORTGROUP = 'kDistributedVirtualPortgroup'

    KTAGCATEGORY = 'kTagCategory'

    KTAG = 'kTag'

    KOPAQUENETWORK = 'kOpaqueNetwork'

    KORGANIZATION = 'kOrganization'

    KVIRTUALDATACENTER = 'kVirtualDatacenter'

    KCATALOG = 'kCatalog'

    KORGMETADATA = 'kOrgMetadata'

    KSTORAGEPOLICY = 'kStoragePolicy'

    KVIRTUALAPPTEMPLATE = 'kVirtualAppTemplate'

    KDOMAIN = 'kDomain'

    KOUTLOOK = 'kOutlook'

    KMAILBOX = 'kMailbox'

    KUSERS = 'kUsers'

    KGROUPS = 'kGroups'

    KSITES = 'kSites'

    KUSER = 'kUser'

    KGROUP = 'kGroup'

    KSITE = 'kSite'

    KAPPLICATION = 'kApplication'

    KGRAPHUSER = 'kGraphUser'

    KPUBLICFOLDERS = 'kPublicFolders'

    KPUBLICFOLDER = 'kPublicFolder'

    KTEAMS = 'kTeams'

    KTEAM = 'kTeam'

    KKEYSPACE = 'kKeyspace'

    KTABLE = 'kTable'

    KDATABASE = 'kDatabase'

    KCOLLECTION = 'kCollection'

    KBUCKET = 'kBucket'

    KNAMESPACE = 'kNamespace'

    KSCVMMSERVER = 'kSCVMMServer'

    KSTANDALONECLUSTER = 'kStandaloneCluster'

    KHOSTGROUP = 'kHostGroup'

    KHYPERVHOST = 'kHypervHost'

    KHOSTCLUSTER = 'kHostCluster'

    KCUSTOMPROPERTY = 'kCustomProperty'

    KSUBSCRIPTION = 'kSubscription'

    KRESOURCEGROUP = 'kResourceGroup'

    KSTORAGEACCOUNT = 'kStorageAccount'

    KSTORAGEKEY = 'kStorageKey'

    KSTORAGECONTAINER = 'kStorageContainer'

    KSTORAGEBLOB = 'kStorageBlob'

    KNETWORKSECURITYGROUP = 'kNetworkSecurityGroup'

    KVIRTUALNETWORK = 'kVirtualNetwork'

    KSUBNET = 'kSubnet'

    KCOMPUTEOPTIONS = 'kComputeOptions'

    KSNAPSHOTMANAGERPERMIT = 'kSnapshotManagerPermit'

    KAVAILABILITYSET = 'kAvailabilitySet'

    KOVIRTMANAGER = 'kOVirtManager'

    KHOST = 'kHost'

    KSTORAGEDOMAIN = 'kStorageDomain'

    KVNICPROFILE = 'kVNicProfile'

    KIAMUSER = 'kIAMUser'

    KREGION = 'kRegion'

    KAVAILABILITYZONE = 'kAvailabilityZone'

    KEC2INSTANCE = 'kEC2Instance'

    KVPC = 'kVPC'

    KINSTANCETYPE = 'kInstanceType'

    KKEYPAIR = 'kKeyPair'

    KRDSOPTIONGROUP = 'kRDSOptionGroup'

    KRDSPARAMETERGROUP = 'kRDSParameterGroup'

    KRDSINSTANCE = 'kRDSInstance'

    KRDSSUBNET = 'kRDSSubnet'

    KRDSTAG = 'kRDSTag'

    KAURORACLUSTER = 'kAuroraCluster'

    KACCOUNT = 'kAccount'

    KSUBTASKPERMIT = 'kSubTaskPermit'

    KPROJECT = 'kProject'

    KLABEL = 'kLabel'

    KMETADATA = 'kMetadata'

    KVPCCONNECTOR = 'kVPCConnector'

    KPRISMCENTRAL = 'kPrismCentral'

    KOTHERHYPERVISORCLUSTER = 'kOtherHypervisorCluster'

    KDFSGROUP = 'kDfsGroup'

    KDFSTOPDIR = 'kDfsTopDir'

    KZONE = 'kZone'

    KMOUNTPOINT = 'kMountPoint'

    KSTORAGEARRAY = 'kStorageArray'

    KFILESYSTEM = 'kFileSystem'

    KCONTAINER = 'kContainer'

    KFILESYSTEM = 'kFilesystem'

    KFILESET = 'kFileset'

    KVIEWBOX = 'kViewBox'

    KVIEW = 'kView'

    KWINDOWSCLUSTER = 'kWindowsCluster'

    KORACLERACCLUSTER = 'kOracleRACCluster'

    KORACLEAPCLUSTER = 'kOracleAPCluster'

    KSERVICE = 'kService'

    KPVC = 'kPVC'

    KROOTCONTAINER = 'kRootContainer'

    KDAGROOTCONTAINER = 'kDAGRootContainer'

    KEXCHANGENODE = 'kExchangeNode'

    KEXCHANGEDAGDATABASECOPY = 'kExchangeDAGDatabaseCopy'

    KEXCHANGESTANDALONEDATABASE = 'kExchangeStandaloneDatabase'

    KEXCHANGEDAG = 'kExchangeDAG'

    KEXCHANGEDAGDATABASE = 'kExchangeDAGDatabase'

    KDOMAINCONTROLLER = 'kDomainController'

    KINSTANCE = 'kInstance'

    KAAG = 'kAAG'

    KAAGROOTCONTAINER = 'kAAGRootContainer'

    KRACROOTCONTAINER = 'kRACRootContainer'

    KTABLESPACE = 'kTableSpace'

    KPDB = 'kPDB'

    KOBJECT = 'kObject'
